/**
 * @since 1.0.0
 */
import { DeleteConnectionCommandInput, DeleteConnectionCommandOutput, GetConnectionCommandInput, GetConnectionCommandOutput, PostToConnectionCommandInput, PostToConnectionCommandOutput } from "@aws-sdk/client-apigatewaymanagementapi";
import { HttpHandlerOptions as __HttpHandlerOptions } from "@aws-sdk/types";
import { Context, Effect, Layer } from "effect";
import { ApiGatewayManagementApiClientInstance } from "./ApiGatewayManagementApiClientInstance";
import { ForbiddenError, GoneError, LimitExceededError, PayloadTooLargeError, SdkError } from "./Errors";
/**
 * @since 1.0.0
 * @category models
 */
export interface ApiGatewayManagementApiService {
    readonly _: unique symbol;
    /**
     * @see {@link DeleteConnectionCommand}
     */
    deleteConnection(args: DeleteConnectionCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | GoneError | ForbiddenError | LimitExceededError, DeleteConnectionCommandOutput>;
    /**
     * @see {@link GetConnectionCommand}
     */
    getConnection(args: GetConnectionCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | GoneError | ForbiddenError | LimitExceededError, GetConnectionCommandOutput>;
    /**
     * @see {@link PostToConnectionCommand}
     */
    postToConnection(args: PostToConnectionCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | GoneError | ForbiddenError | LimitExceededError | PayloadTooLargeError, PostToConnectionCommandOutput>;
}
/**
 * @since 1.0.0
 * @category tags
 */
export declare const ApiGatewayManagementApiService: Context.Tag<ApiGatewayManagementApiService, ApiGatewayManagementApiService>;
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeApiGatewayManagementApiService: Effect.Effect<ApiGatewayManagementApiClientInstance, never, ApiGatewayManagementApiService>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const BaseApiGatewayManagementApiServiceLayer: Layer.Layer<ApiGatewayManagementApiClientInstance, never, ApiGatewayManagementApiService>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const ApiGatewayManagementApiServiceLayer: Layer.Layer<import("./ApiGatewayManagementApiClientInstanceConfig").ApiGatewayManagementApiClientInstanceConfig, never, ApiGatewayManagementApiService>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const DefaultApiGatewayManagementApiServiceLayer: Layer.Layer<never, never, ApiGatewayManagementApiService>;
/**
 * @since 0.1.0
 * @deprecated
 */
export declare const BaseApiGatewayManagementApiServiceEffect: Effect.Effect<ApiGatewayManagementApiClientInstance, never, ApiGatewayManagementApiService>;
/**
 * @since 0.1.0
 * @deprecated
 */
export declare const ApiGatewayManagementApiServiceEffect: Effect.Effect<import("./ApiGatewayManagementApiClientInstanceConfig").ApiGatewayManagementApiClientInstanceConfig, never, ApiGatewayManagementApiService>;
/**
 * @since 0.1.0
 * @deprecated
 */
export declare const DefaultApiGatewayManagementApiServiceEffect: Effect.Effect<never, never, ApiGatewayManagementApiService>;
